Enum cpp_demangle::ast::LocalName
[−]
[src]
pub enum LocalName {
Relative(Box<Encoding>, Option<Box<Name>>, Option<Discriminator>),
Default(Box<Encoding>, Option<usize>, Box<Name>),
}The <local-name> production.
<local-name> := Z <function encoding> E <entity name> [<discriminator>]
:= Z <function encoding> E s [<discriminator>]
:= Z <function encoding> Ed [ <parameter number> ] _ <entity name>
Variants
Relative(Box<Encoding>, Option<Box<Name>>, Option<Discriminator>)The mangling of the enclosing function, the mangling of the entity relative to the function, and an optional discriminator.
Default(Box<Encoding>, Option<usize>, Box<Name>)A default argument in a class definition.