Enum cpp_demangle::ast::MangledName
[−]
[src]
pub enum MangledName {
Encoding(Encoding),
Type(TypeHandle),
}The root AST node, and starting production.
<mangled-name> ::= _Z <encoding>
Variants
Encoding(Encoding)The encoding of the mangled symbol name.
Type(TypeHandle)A top-level type. Technically not allowed by the standard, however in practice this can happen, and is tested for by libiberty.