Struct cpp_demangle::ast::ArgScopeStack
[−]
[src]
pub struct ArgScopeStack<'prev, 'subs> where
'subs: 'prev, { /* fields omitted */ }An ArgScopeStack represents the current function and template demangling
scope we are within. As we enter new demangling scopes, we construct new
ArgScopeStacks whose prev references point back to the old ones. These
ArgScopeStacks are kept on the native stack, and as functions return, they
go out of scope and we use the previous ArgScopeStacks again.