Struct cpp_demangle::ast::Identifier
[−]
[src]
pub struct Identifier { /* fields omitted */ }The <identifier> pseudo-terminal.
<identifier> ::= <unqualified source code identifier>
<identifier>is a pseudo-terminal representing the characters in the unqualified identifier for the entity in the source code. This ABI does not yet specify a mangling for identifiers containing characters outside of_A-Za-z0-9..